..
    Copyright (c) 2018 Bobby Noelte
    SPDX-License-Identifier: Apache-2.0

.. _cogeno_getting_started:

Getting started
###############

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   invoke_cogeno
   invoke_edtsdatabase
   scripting
   build
